import { TBreakpoint, TBreakpoints } from '@/components/Grid/layout-definition';
import { IColumns } from '@/components/Grid/grid-layout-props.interface';
/**
 * Given breakpoints, return an array of breakpoints sorted by width. This is usually
 * e.g. ['xxs', 'xs', 'sm', ...]
 *
 * @param  {TBreakpoints}   breakpoints   Key/value a pair of breakpoint names to widths.
 * @return {TBreakpoint[]}                Sorted breakpoints.
 */
export declare const sortBreakpoints: (breakpoints: TBreakpoints) => TBreakpoint[];
/**
 * Given a width, find the highest breakpoint that matches is valid for it (width > breakpoint).
 *
 * @param  {TBreakpoints} breakpoints Breakpoints object (e.g. {lg: 1200, md: 960, ...})
 * @param  {Number}       width       Window width.
 * @return {TBreakpoint}              Highest breakpoint that is less than width.
 * @throws {Error}                    Invalid width. Must be greater or equal 0
 */
export declare const getBreakpointFromWidth: (breakpoints: TBreakpoints, width: number) => TBreakpoint;
/**
 * Given a breakpoint, get the # of cols set for it.
 *
 * @param  {TBreakpoint}  breakpoint  Breakpoint.
 * @param  {IColumns}     cols        Map of breakpoints to cols.
 * @return {Number}                   Number of cols.
 * @throws {Error}                    Column not found
 */
export declare const getColsFromBreakpoint: (breakpoint: TBreakpoint, cols: IColumns) => number;
