import { ILayoutItem, TLayout } from '@/components';
import { TMovingDirection } from '@/core/common/types/TMovingDirections';
/**
 * Moving a GridItem to the correct place in the layout.
 *
 * @param {ILayoutItem}     layoutItem
 * @param {ILayoutItem}     bounds
 * @param {ILayoutItem[]}   staticItems
 */
export declare const moveToCorrectPlace: (layoutItem: ILayoutItem, bounds: {
    cols: number;
}, staticItems: ILayoutItem[]) => void;
/**
 * Move an element. Responsible for doing cascading movements of other elements.
 *
 * @param  {TLayout}      layout              Full layout to modify.
 * @param  {ILayoutItem}  l                   element to move.
 * @param  {Number}       [x]                 X position in grid units.
 * @param  {Number}       [y]                 Y position in grid units.
 * @param  {Boolean}      [isUserAction]      If true, designates that the item we're moving is being dragged/resized by the user.
 * @param  {Boolean}      [horizontalShift]   If true, the GridItems will move left or right when the moving element is passing over a GridItem.
 * @param  {Boolean}      [preventCollision]  If true, the moving element will not be moving other elements to make space for a possible drop.
 * @return {TLayout}                          The updated layout.
 */
export declare function moveElement(layout: TLayout, l: ILayoutItem, x: number, y: number, isUserAction: boolean, horizontalShift: boolean, preventCollision?: boolean): TLayout;
/**
 * This is where the magic needs to happen - given a collision, move an element away from the collision.
 * We attempt to move it up if there's room, otherwise it goes below.
 *
 * @param  {TLayout} layout             Full layout to modify.
 * @param  {ILayoutItem} collidesWith   Layout item we're colliding with.
 * @param  {ILayoutItem} itemToMove     Layout item we're moving.
 * @param  {Boolean} [isUserAction]     If true, designates that the item we're moving is being dragged/resized by the user.
 * @param  {Boolean} [movingDirection]
 * @param  {Boolean} [horizontalShift]
 * @return {TLayout}                    The modified layout.
 */
export declare function moveElementAwayFromCollision(layout: TLayout, collidesWith: ILayoutItem, itemToMove: ILayoutItem, isUserAction: boolean, movingDirection: TMovingDirection, horizontalShift: boolean): TLayout;
