import { ILayoutItem, TLayout } from '@/components/Grid/layout-definition';
import { ITopLeftStyle, ITopRightStyle, ITransformStyle } from '@/core/common/interfaces/transformStyle.interfaces';
export declare function cloneLayoutItem(layoutItem: ILayoutItem): ILayoutItem;
export declare function cloneLayout(layout: TLayout): TLayout;
/**
 *
 * @param compareWith
 * @param layoutItem
 * @param verticalCompact
 * @param minPositions
 * @returns {ILayoutItem}
 */
export declare function compactItem(compareWith: TLayout, layoutItem: ILayoutItem, verticalCompact: boolean, minPositions?: any): ILayoutItem;
/**
 * Given a layout, compact it. This involves going down each y coordinate and removing gaps
 * between items.
 *
 * @param   {TLayout} layout          Layout.
 * @param   {Boolean} verticalCompact Whether or not to compact the layout vertically.
 * @param   {Object}  minPositions
 * @return  {TLayout}                 Compacted Layout.
 */
export declare function compactLayout(layout: TLayout, verticalCompact: boolean, minPositions?: any): TLayout;
/**
 * Get a layout item by ID. Used so we can override later on if necessary.
 *
 * @param  {Array}      layout  Layout array.
 * @param  {String}     id      ID
 * @return {ILayoutItem}        Item at ID.
 * @throws {Error}              Invalid parameters
 */
export declare function getLayoutItem(layout: TLayout, id: string | number | undefined): ILayoutItem | undefined;
/**
 * Returns default direction
 *
 * @param top
 * @param left
 * @param width
 * @param height
 * @returns {ITransformStyle}
 */
export declare function setTransform(top: number, left: number, width: number, height: number): ITransformStyle;
/**
 * Just like the setTransform method, but instead it will return a negative value of right.
 *
 * @param top
 * @param right
 * @param width
 * @param height
 * @returns {ITransformStyle}
 */
export declare function setTransformRtl(top: number, right: number, width: number, height: number): ITransformStyle;
/**
 * Getting top left css values from numeric coordinates
 * @param top
 * @param left
 * @param width
 * @param height
 * @returns {ITopLeftStyle}
 */
export declare function setTopLeft(top: number, left: number, width: number, height: number): ITopLeftStyle;
/**
 * Just like the setTopLeft method, but instead, it will return a right property instead of left.
 *
 * @param top
 * @param right
 * @param width
 * @param height
 * @returns {ITopRightStyle}
 */
export declare function setTopRight(top: number, right: number, width: number, height: number): ITopRightStyle;
